[PATCH 2 of 4] help: hide template keywords of obsolescence as they are still experimental

Yuya Nishihara yuya at tcha.org
Thu Oct 12 09:55:42 EDT 2017


# HG changeset patch
# User Yuya Nishihara <yuya at tcha.org>
# Date 1507812482 -32400
#      Thu Oct 12 21:48:02 2017 +0900
# Node ID a6cf3a279553d5b089c90585789033988756a24d
# Parent  d979476b95c0b301988655ee0ec1d7c53fcfa7a0
help: hide template keywords of obsolescence as they are still experimental

diff --git a/mercurial/templatekw.py b/mercurial/templatekw.py
--- a/mercurial/templatekw.py
+++ b/mercurial/templatekw.py
@@ -648,8 +648,7 @@ def shownode(repo, ctx, templ, **args):
 
 @templatekeyword('obsolete')
 def showobsolete(repo, ctx, templ, **args):
     """String. Whether the changeset is obsolete.
     """
     if ctx.obsolete():
         return 'obsolete'
     return ''
@@ -670,7 +669,7 @@ def showpeerurls(repo, **args):
 
 @templatekeyword("predecessors")
 def showpredecessors(repo, ctx, **args):
     """Returns the list if the closest visible successors."""
     predecessors = sorted(obsutil.closestpredecessors(repo, ctx.node()))
     predecessors = map(hex, predecessors)
 
@@ -682,7 +681,7 @@ def showpredecessors(repo, ctx, **args):
 def showsuccessorssets(repo, ctx, **args):
     """Returns a string of sets of successors for a changectx. Format used
     is: [ctx1, ctx2], [ctx3] if ctx has been splitted into ctx1 and ctx2
-    while also diverged into ctx3."""
+    while also diverged into ctx3. (EXPERIMENTAL)"""
     if not ctx.obsolete():
         return ''
     args = pycompat.byteskwargs(args)
@@ -648,8 +648,7 @@ def shownode(repo, ctx, templ, **args):
 @templatekeyword('obsolete')
 def showobsolete(repo, ctx, templ, **args):
-    """String. Whether the changeset is obsolete.
-    """
+    """String. Whether the changeset is obsolete. (EXPERIMENTAL)"""
     if ctx.obsolete():
         return 'obsolete'
@@ -670,7 +669,7 @@ def showpeerurls(repo, **args):
 @templatekeyword("predecessors")
 def showpredecessors(repo, ctx, **args):
-    """Returns the list if the closest visible successors."""
+    """Returns the list if the closest visible successors. (EXPERIMENTAL)"""
     predecessors = sorted(obsutil.closestpredecessors(repo, ctx.node()))
     predecessors = map(hex, predecessors)


More information about the Mercurial-devel mailing list